@@ -10,7 +10,7 @@ use Mojo::Promise;
 
 use constant DEBUG => $ENV{MOJO_GRAPHITE_WRITER_DEBUG};
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 $VERSION = eval $VERSION;
 
 has address    => sub { Carp::croak 'address is required' };
@@ -233,8 +233,7 @@ The promise is rejected if any write in the write queue fails, even if it is not
 
 =head1 FUTURE WORK
 
-This module is still in early development.
-Future work will include
+Future work may include
 
 =over
 
